summaryrefslogtreecommitdiffstats
path: root/WebCore/platform/graphics/android/android_graphics.h
diff options
context:
space:
mode:
authorCary Clark <cary@android.com>2009-05-29 10:55:15 -0400
committerCary Clark <cary@android.com>2009-06-01 16:11:38 -0400
commit46dfee13b2bec1b39f46c138df565b2207ccbc86 (patch)
tree567b54c6da71adcef3840717d082bfb908b71634 /WebCore/platform/graphics/android/android_graphics.h
parentd0c887c5d9f5595e0c2075f65976def2282f9b42 (diff)
downloadexternal_webkit-46dfee13b2bec1b39f46c138df565b2207ccbc86.zip
external_webkit-46dfee13b2bec1b39f46c138df565b2207ccbc86.tar.gz
external_webkit-46dfee13b2bec1b39f46c138df565b2207ccbc86.tar.bz2
in the browser, make the trackball more like a mouse
Older code treated the trackball as a four way dpad with equivalents to moving up, down, left and right by generating arrow key events. This change makes the trackball solely generate mousemove events. The old arrow keys in turn were mapped to be as close as possible to tab-key events that moved the focus. The new model leaves focus-changes to the DOM. Clicking the dpad is distinguished from pressing the enter key to be more compatible with desktop-authored web pages.
Diffstat (limited to 'WebCore/platform/graphics/android/android_graphics.h')
-rw-r--r--WebCore/platform/graphics/android/android_graphics.h15
1 files changed, 7 insertions, 8 deletions
diff --git a/WebCore/platform/graphics/android/android_graphics.h b/WebCore/platform/graphics/android/android_graphics.h
index 0853d85..d60c10b 100644
--- a/WebCore/platform/graphics/android/android_graphics.h
+++ b/WebCore/platform/graphics/android/android_graphics.h
@@ -39,15 +39,15 @@ namespace WebCore {
SkCanvas* android_gc2canvas(WebCore::GraphicsContext* gc);
// Data and methods for focus rings
// used to inflate node cache entry
-#define FOCUS_RING_HIT_TEST_RADIUS 5
+#define CURSOR_RING_HIT_TEST_RADIUS 5
-// used to inval rectangle enclosing pressed state of focus ring
-#define FOCUS_RING_OUTER_DIAMETER SkFixedToScalar(SkIntToFixed(13)>>2) // 13/4 == 3.25
+// used to inval rectangle enclosing pressed state of ring
+#define CURSOR_RING_OUTER_DIAMETER SkFixedToScalar(SkIntToFixed(13)>>2) // 13/4 == 3.25
-struct FocusRing {
+struct CursorRing {
public:
enum Flavor {
NORMAL_FLAVOR,
@@ -57,10 +57,9 @@ public:
FAKE_ANIMATING,
ANIMATING_COUNT = 2
};
-
- static void DrawRing(SkCanvas* ,
+
+ static void DrawRing(SkCanvas* ,
const Vector<WebCore::IntRect>& rects, Flavor );
};
#endif
-
@@ -39,15 +39,15 @@ namespace WebCore {
SkCanvas* android_gc2canvas(WebCore::GraphicsContext* gc);
-// Data and methods for focus rings
+// Data and methods for cursor rings
// used to inflate node cache entry